@@ -56,7 +56,7 @@ public class BiasedBarcodeCollectionFactory {
 		return new UMIIterator(SamFileMergeUtil.mergeInputs(inputFiles, false, samReaderFactory),
 				GeneFunctionCommandLineBase.DEFAULT_GENE_NAME_TAG, GeneFunctionCommandLineBase.DEFAULT_GENE_STRAND_TAG,
 				GeneFunctionCommandLineBase.DEFAULT_GENE_FUNCTION_TAG, GeneFunctionCommandLineBase.DEFAULT_STRAND_STRATEGY,
-				GeneFunctionCommandLineBase.DEFAULT_LOCUS_FUNCTION_LIST,
+				GeneFunctionCommandLineBase.DEFAULT_LOCUS_FUNCTION_LIST, GeneFunctionCommandLineBase.DEFAULT_FUNCTIONAL_STRATEGY,
 				cellBarcodeTag, molBCTag, readMQ, false, cellBarcodes, true, false);
 
 	}
