@@ -35,7 +35,7 @@ import java.util.List;
 import java.util.Map;
 import java.util.Set;
 
-import org.apache.commons.lang.StringUtils;
+import org.apache.commons.lang3.StringUtils;
 import org.broadinstitute.barclay.argparser.Argument;
 import org.broadinstitute.barclay.argparser.CommandLineProgramProperties;
 import org.broadinstitute.dropseqrna.TranscriptomeException;
@@ -315,7 +315,7 @@ public class DetectBeadSynthesisErrors extends GeneFunctionCommandLineBase {
             umiBias.put(bsed.getCellBarcode(), barcodeUMIBias);
 
             // finalize object so it uses less memory.
-            bsed.finalize();
+            bsed.finalizeData();
             // only add to the collection if you have UMIs and a repairable error.
             if (bsed.getUMICount()>=this.MIN_UMIS_PER_CELL && errorType==BeadSynthesisErrorType.SYNTH_MISSING_BASE)
             	errorBarcodesWithPositions.put(bsed.getCellBarcode(), bsed);
@@ -590,7 +590,7 @@ public class DetectBeadSynthesisErrors extends GeneFunctionCommandLineBase {
 
 		UMIIterator umiIterator = new UMIIterator(SamFileMergeUtil.mergeInputs(INPUT, false, samReaderFactory),
 				GENE_NAME_TAG, GENE_STRAND_TAG, GENE_FUNCTION_TAG,
-        		this.STRAND_STRATEGY, this.LOCUS_FUNCTION_LIST, this.CELL_BARCODE_TAG, this.MOLECULAR_BARCODE_TAG,
+        		this.STRAND_STRATEGY, this.LOCUS_FUNCTION_LIST, this.FUNCTIONAL_STRATEGY, this.CELL_BARCODE_TAG, this.MOLECULAR_BARCODE_TAG,
         		this.READ_MQ, false, barcodes, true, false);
 
 				return (umiIterator);
